﻿/*
 This file is part of ELoadV1.

    ELoadV1 is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    ELoadV1 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with ELoadV1.  If not, see <http://www.gnu.org/licenses/>.
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

/*
 Loads or writes a configfile with the syntax
    identifier = value
    # comments
Class is not Exeption safe! (to be used in try-catch blocks)
     */

namespace ELoadV1
{

    class ConfigFileReader
    {
        public ConfigFileReader(string file_path)
        {
            file_name = file_path;
            fail_cnt = 0;
        }
        public void ReadConfigFile()
        {
            file_data = System.IO.File.ReadAllLines(file_name);
            int i;
            for (i = 0; i < file_data.Length; i++)
            {
                file_data[i] = file_data[i].Replace(" ", "");//Remove the excess spaces
                
            }
        }

        
        public float GetFloatFromFile(string identifier)
        {
            short i;
            string[] vals;
            for (i = 0; i < file_data.Length; i++)
            {
                if (file_data[i] != "" && file_data[i].First() != '#')
                {
                    //No comment
                    //Split the data into identifier and value
                    if (file_data[i].Contains("="))
                    {
                        vals = file_data[i].Split('=');
                        if (vals.Length == 2)
                        {
                            if (identifier == vals[0])
                            {
                                return float.Parse(vals[1]);
                            }
                        }
                    }
                }
            }
            fail_cnt++;
            return float.NaN;
        }

        public int GetIntFromFile(string identifier)
        {
            short i;
            string[] vals;
            for (i = 0; i < file_data.Length; i++)
            {
                if (file_data[i] != "" && file_data[i].First() != '#')
                {
                    //No comment
                    //Split the data into identifier and value
                    if (file_data[i].Contains("="))
                    {
                        vals = file_data[i].Split('=');
                        if (vals.Length == 2)
                        {
                            if (identifier == vals[0])
                            {
                                return int.Parse(vals[1]);
                            }
                        }
                    }
                }
            }
            fail_cnt++;
            return 0;
        }

        public bool IdentifierExistsInFile(string identifier)
        {

            short i;
            string[] vals;
            for (i = 0; i < file_data.Length; i++)
            {
                if (file_data[i] != "" && file_data[i].First() != '#')
                {
                    //No comment
                    //Split the data into identifier and value
                    if (file_data[i].Contains("="))
                    {
                        vals = file_data[i].Split('=');
                        if (identifier == vals[0])
                        {
                            return true;
                        }
                    }
                    
                }
            }
            return false;
        }

        public bool HasFailedAtLeastOnce()
        {
            return (fail_cnt > 0);
        }

        private string file_name;
        private string[] file_data;
        private short fail_cnt;
    }
    class ConfigFileWriter
    {
        public ConfigFileWriter(string file_path)
        {
            file_name = file_path;
            file_data = "#";
            AddCommentLine("#Configfile: Syntax: ");
            AddCommentLine("#Identifier = value");
            AddCommentLine("#Comments begin with a #");
        }
        public void WriteConfigFile()
        {
            System.IO.File.WriteAllText(file_name, file_data);
        }

        public void AddIntToFile(string identifier, int value)
        {
            file_data += Environment.NewLine + identifier + " = " + value.ToString();
        }
        public void AddIntToFile(string identifier, int value, string comment)
        {
            file_data += Environment.NewLine + "#--<" + identifier + "> <<" + comment + ">>";
            file_data += Environment.NewLine + identifier + " = " + value.ToString();
        }

        public void AddFloatToFile(string identifier, float value)
        {
            file_data += Environment.NewLine + identifier + " = " + value.ToString();
        }
        public void AddFloatToFile(string identifier, float value, string comment)
        {
            file_data += Environment.NewLine + "#--<" + identifier + "> <<" + comment + ">>";
            file_data += Environment.NewLine + identifier + " = " + value.ToString();
        }
        public void AddCommentLine(string comment)
        {
            file_data += Environment.NewLine + "#--<<" + comment + ">>";
        }
        private string file_name;
        private string file_data;
    }
}
